# Changelog

This is an auto-generated log of all the changes that have been made to the
project since the first release.

This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.9.0](https://github.com/seapagan/simple-toml-settings/releases/tag/0.9.0) (2025-01-16)

**New Features**

- Fix compatibility with python 3.13 ([#296](https://github.com/seapagan/simple-toml-settings/pull/296)) by [seapagan](https://github.com/seapagan)
- Migrate from poetry to uv ([#285](https://github.com/seapagan/simple-toml-settings/pull/285)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump jinja2 from 3.1.4 to 3.1.5 ([#295](https://github.com/seapagan/simple-toml-settings/pull/295)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Update astral-sh/setup-uv action to v5 ([#294](https://github.com/seapagan/simple-toml-settings/pull/294)) by [renovate[bot]](https://github.com/apps/renovate)

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.8.0...0.9.0) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.8.0...0.9.0.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.8.0...0.9.0.patch)

## [0.8.0](https://github.com/seapagan/simple-toml-settings/releases/tag/0.8.0) (2024-08-22)

**New Features**

- Add 'allow_missing_file' option ([#254](https://github.com/seapagan/simple-toml-settings/pull/254)) by [seapagan](https://github.com/seapagan)
- Mark some options as mutually exclusive and raise exception if more than one used ([#245](https://github.com/seapagan/simple-toml-settings/pull/245)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump mkdocs-material from 9.5.31 to 9.5.32 ([#253](https://github.com/seapagan/simple-toml-settings/pull/253)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump github-changelog-md from 0.9.4 to 0.9.5 ([#252](https://github.com/seapagan/simple-toml-settings/pull/252)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 26.1.0 to 27.0.0 ([#251](https://github.com/seapagan/simple-toml-settings/pull/251)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump ruff from 0.5.6 to 0.6.1 ([#250](https://github.com/seapagan/simple-toml-settings/pull/250)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pymarkdownlnt from 0.9.21 to 0.9.22 ([#247](https://github.com/seapagan/simple-toml-settings/pull/247)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mypy from 1.11.0 to 1.11.1 ([#243](https://github.com/seapagan/simple-toml-settings/pull/243)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-material from 9.5.30 to 9.5.31 ([#242](https://github.com/seapagan/simple-toml-settings/pull/242)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 26.0.0 to 26.1.0 ([#241](https://github.com/seapagan/simple-toml-settings/pull/241)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump ruff from 0.5.5 to 0.5.6 ([#240](https://github.com/seapagan/simple-toml-settings/pull/240)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pytest from 8.2.2 to 8.3.2 ([#239](https://github.com/seapagan/simple-toml-settings/pull/239)) by [dependabot[bot]](https://github.com/apps/dependabot)
- *and 3 more dependency updates*

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.7.0...0.8.0) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.7.0...0.8.0.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.7.0...0.8.0.patch)

## [0.7.0](https://github.com/seapagan/simple-toml-settings/releases/tag/0.7.0) (2024-07-29)

**New Features**

- Add option to use the `XDG_CONFIG_HOME` env variable or standard default if not set ([#231](https://github.com/seapagan/simple-toml-settings/pull/231)) by [borland502](https://github.com/borland502)

**Bug Fixes**

- Disable coverage upload if token not set ([#232](https://github.com/seapagan/simple-toml-settings/pull/232)) by [seapagan](https://github.com/seapagan)

**Documentation**

- Document the new XDG option ([#234](https://github.com/seapagan/simple-toml-settings/pull/234)) by [seapagan](https://github.com/seapagan)
- Clarify contribution information ([#218](https://github.com/seapagan/simple-toml-settings/pull/218)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump ruff from 0.5.1 to 0.5.5 ([#233](https://github.com/seapagan/simple-toml-settings/pull/233)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mypy from 1.10.1 to 1.11.0 ([#229](https://github.com/seapagan/simple-toml-settings/pull/229)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump poethepoet from 0.26.1 to 0.27.0 ([#228](https://github.com/seapagan/simple-toml-settings/pull/228)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pymarkdownlnt from 0.9.20 to 0.9.21 ([#227](https://github.com/seapagan/simple-toml-settings/pull/227)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump setuptools from 69.1.1 to 70.0.0 ([#225](https://github.com/seapagan/simple-toml-settings/pull/225)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump rtoml from 0.10.0 to 0.11.0 ([#223](https://github.com/seapagan/simple-toml-settings/pull/223)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mypy from 1.10.0 to 1.10.1 ([#222](https://github.com/seapagan/simple-toml-settings/pull/222)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump github-changelog-md from 0.9.3 to 0.9.4 ([#221](https://github.com/seapagan/simple-toml-settings/pull/221)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pyfakefs from 5.5.0 to 5.6.0 ([#220](https://github.com/seapagan/simple-toml-settings/pull/220)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-material from 9.5.28 to 9.5.29 ([#219](https://github.com/seapagan/simple-toml-settings/pull/219)) by [dependabot[bot]](https://github.com/apps/dependabot)
- *and 18 more dependency updates*

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.6.1...0.7.0) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.6.1...0.7.0.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.6.1...0.7.0.patch)

## [0.6.1](https://github.com/seapagan/simple-toml-settings/releases/tag/0.6.1) (2024-05-02)

**New Features**

- Relax some dependency version specs ([#179](https://github.com/seapagan/simple-toml-settings/pull/179)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump poethepoet from 0.25.0 to 0.26.1 ([#178](https://github.com/seapagan/simple-toml-settings/pull/178)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-material from 9.5.17 to 9.5.20 ([#176](https://github.com/seapagan/simple-toml-settings/pull/176)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pytest from 8.1.1 to 8.2.0 ([#174](https://github.com/seapagan/simple-toml-settings/pull/174)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pymdown-extensions from 10.7.1 to 10.8.1 ([#173](https://github.com/seapagan/simple-toml-settings/pull/173)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mypy from 1.9.0 to 1.10.0 ([#172](https://github.com/seapagan/simple-toml-settings/pull/172)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump ruff from 0.3.5 to 0.4.2 ([#171](https://github.com/seapagan/simple-toml-settings/pull/171)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 24.3.0 to 24.14.0 ([#170](https://github.com/seapagan/simple-toml-settings/pull/170)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pyfakefs from 5.3.5 to 5.4.1 ([#165](https://github.com/seapagan/simple-toml-settings/pull/165)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump idna from 3.6 to 3.7 ([#164](https://github.com/seapagan/simple-toml-settings/pull/164)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pytest-watcher from 0.4.1 to 0.4.2 ([#159](https://github.com/seapagan/simple-toml-settings/pull/159)) by [dependabot[bot]](https://github.com/apps/dependabot)
- *and 9 more dependency updates*

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.6.0...0.6.1) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.6.0...0.6.1.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.6.0...0.6.1.patch)

## [0.6.0](https://github.com/seapagan/simple-toml-settings/releases/tag/0.6.0) (2024-03-11)

**New Features**

- Implement a `flat_config` option. ([#142](https://github.com/seapagan/simple-toml-settings/pull/142)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump ruff from 0.3.1 to 0.3.2 ([#141](https://github.com/seapagan/simple-toml-settings/pull/141)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mypy from 1.8.0 to 1.9.0 ([#140](https://github.com/seapagan/simple-toml-settings/pull/140)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 24.0.0 to 24.1.0 ([#139](https://github.com/seapagan/simple-toml-settings/pull/139)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pytest from 8.0.2 to 8.1.1 ([#138](https://github.com/seapagan/simple-toml-settings/pull/138)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.5.0...0.6.0) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.5.0...0.6.0.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.5.0...0.6.0.patch)

## [0.5.0](https://github.com/seapagan/simple-toml-settings/releases/tag/0.5.0) (2024-03-07)

**Closed Issues**


**New Features**

- Add an optional singleton method ([#136](https://github.com/seapagan/simple-toml-settings/pull/136)) by [seapagan](https://github.com/seapagan)

**Refactoring**

- Fix formatting to Ruff 3.0 standard ([#131](https://github.com/seapagan/simple-toml-settings/pull/131)) by [seapagan](https://github.com/seapagan)

**Documentation**

- Fix some errors and typos in the docs ([#124](https://github.com/seapagan/simple-toml-settings/pull/124)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump mkdocs-material from 9.5.9 to 9.5.13 ([#135](https://github.com/seapagan/simple-toml-settings/pull/135)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 23.1.0 to 24.0.0 ([#134](https://github.com/seapagan/simple-toml-settings/pull/134)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-autorefs from 0.5.0 to 1.0.1 ([#133](https://github.com/seapagan/simple-toml-settings/pull/133)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump ruff from 0.2.1 to 0.3.0 ([#130](https://github.com/seapagan/simple-toml-settings/pull/130)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump poethepoet from 0.24.4 to 0.25.0 ([#126](https://github.com/seapagan/simple-toml-settings/pull/126)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump cryptography from 42.0.0 to 42.0.4 ([#123](https://github.com/seapagan/simple-toml-settings/pull/123)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump github-changelog-md from 0.8.1 to 0.9.1 ([#122](https://github.com/seapagan/simple-toml-settings/pull/122)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.4.0...0.5.0) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.4.0...0.5.0.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.4.0...0.5.0.patch)

## [0.4.0](https://github.com/seapagan/simple-toml-settings/releases/tag/0.4.0) (2024-02-14)

**New Features**

- Raise schema error if the file schema does not match the required schema ([#111](https://github.com/seapagan/simple-toml-settings/pull/111)) by [seapagan](https://github.com/seapagan)

**Documentation**

- Add a SECURITY file ([#120](https://github.com/seapagan/simple-toml-settings/pull/120)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump mypy from 1.7.1 to 1.8.0 ([#119](https://github.com/seapagan/simple-toml-settings/pull/119)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pymarkdownlnt from 0.9.15 to 0.9.17 ([#118](https://github.com/seapagan/simple-toml-settings/pull/118)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pre-commit from 3.6.0 to 3.6.1 ([#117](https://github.com/seapagan/simple-toml-settings/pull/117)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump ruff from 0.1.8 to 0.2.1 ([#116](https://github.com/seapagan/simple-toml-settings/pull/116)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pytest-sugar from 0.9.7 to 1.0.0 ([#115](https://github.com/seapagan/simple-toml-settings/pull/115)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump github-changelog-md from 0.8.0 to 0.8.1 ([#114](https://github.com/seapagan/simple-toml-settings/pull/114)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pytest from 7.4.3 to 8.0.0 ([#113](https://github.com/seapagan/simple-toml-settings/pull/113)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-material from 9.5.2 to 9.5.9 ([#112](https://github.com/seapagan/simple-toml-settings/pull/112)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 20.0.3 to 23.1.0 ([#110](https://github.com/seapagan/simple-toml-settings/pull/110)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump cryptography from 41.0.6 to 42.0.0 ([#107](https://github.com/seapagan/simple-toml-settings/pull/107)) by [dependabot[bot]](https://github.com/apps/dependabot)
- *and 33 more dependency updates*

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.3.2...0.4.0) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.3.2...0.4.0.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.3.2...0.4.0.patch)

## [0.3.2](https://github.com/seapagan/simple-toml-settings/releases/tag/0.3.2) (2023-11-02)

**Bug Fixes**

- Don't save `None` values to the TOML file. ([#49](https://github.com/seapagan/simple-toml-settings/pull/49)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump pymarkdownlnt from 0.9.13.4 to 0.9.14 ([#48](https://github.com/seapagan/simple-toml-settings/pull/48)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 19.12.1 to 19.13.0 ([#47](https://github.com/seapagan/simple-toml-settings/pull/47)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump github-changelog-md from 0.3.0 to 0.5.0 ([#46](https://github.com/seapagan/simple-toml-settings/pull/46)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 19.11.0 to 19.12.1 ([#45](https://github.com/seapagan/simple-toml-settings/pull/45)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pytest-asyncio from 0.21.1 to 0.22.0 ([#44](https://github.com/seapagan/simple-toml-settings/pull/44)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pytest from 7.4.2 to 7.4.3 ([#42](https://github.com/seapagan/simple-toml-settings/pull/42)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-material from 9.4.6 to 9.4.7 ([#41](https://github.com/seapagan/simple-toml-settings/pull/41)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.3.1...0.3.2) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.3.1...0.3.2.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.3.1...0.3.2.patch)

## [0.3.1](https://github.com/seapagan/simple-toml-settings/releases/tag/0.3.1) (2023-10-28)

**Refactoring**

- Change to new CHANGELOG generator. Mine :) ([#38](https://github.com/seapagan/simple-toml-settings/pull/38)) by [seapagan](https://github.com/seapagan)
- Migrate to ruff linter and formatter ([#37](https://github.com/seapagan/simple-toml-settings/pull/37)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump black from 23.10.0 to 23.10.1 ([#36](https://github.com/seapagan/simple-toml-settings/pull/36)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pylint from 3.0.1 to 3.0.2 ([#35](https://github.com/seapagan/simple-toml-settings/pull/35)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pylint-pytest from 1.1.2 to 1.1.3 ([#34](https://github.com/seapagan/simple-toml-settings/pull/34)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pytest-mock from 3.11.1 to 3.12.0 ([#33](https://github.com/seapagan/simple-toml-settings/pull/33)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pymdown-extensions from 10.3 to 10.3.1 ([#32](https://github.com/seapagan/simple-toml-settings/pull/32)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 19.10.0 to 19.11.0 ([#31](https://github.com/seapagan/simple-toml-settings/pull/31)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump black from 23.9.1 to 23.10.0 ([#30](https://github.com/seapagan/simple-toml-settings/pull/30)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump flake8-type-checking from 2.5.0 to 2.5.1 ([#29](https://github.com/seapagan/simple-toml-settings/pull/29)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mypy from 1.6.0 to 1.6.1 ([#28](https://github.com/seapagan/simple-toml-settings/pull/28)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.3.0...0.3.1) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.3.0...0.3.1.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.3.0...0.3.1.patch)

## [0.3.0](https://github.com/seapagan/simple-toml-settings/releases/tag/0.3.0) (2023-10-18)

**New Features**

- Allow a Local config file ([#25](https://github.com/seapagan/simple-toml-settings/pull/25)) by [seapagan](https://github.com/seapagan)
- Add 'auto_create' option for config file, default True ([#22](https://github.com/seapagan/simple-toml-settings/pull/22)) by [seapagan](https://github.com/seapagan)

**Documentation**

- Add missing repo section to docs ([#21](https://github.com/seapagan/simple-toml-settings/pull/21)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump urllib3 from 2.0.6 to 2.0.7 ([#27](https://github.com/seapagan/simple-toml-settings/pull/27)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump flake8-type-checking from 2.4.2 to 2.5.0 ([#26](https://github.com/seapagan/simple-toml-settings/pull/26)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-material from 9.4.5 to 9.4.6 ([#24](https://github.com/seapagan/simple-toml-settings/pull/24)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pre-commit from 3.4.0 to 3.5.0 ([#23](https://github.com/seapagan/simple-toml-settings/pull/23)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pyfakefs from 5.2.4 to 5.3.0 ([#20](https://github.com/seapagan/simple-toml-settings/pull/20)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 19.9.0 to 19.10.0 ([#19](https://github.com/seapagan/simple-toml-settings/pull/19)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.2.2...0.3.0) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.2.2...0.3.0.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.2.2...0.3.0.patch)

## [0.2.2](https://github.com/seapagan/simple-toml-settings/releases/tag/0.2.2) (2023-10-12)

**Bug Fixes**

- Docs: fix same example error in README ([#18](https://github.com/seapagan/simple-toml-settings/pull/18)) by [seapagan](https://github.com/seapagan)
- Fix error on docs front page example code ([#17](https://github.com/seapagan/simple-toml-settings/pull/17)) by [seapagan](https://github.com/seapagan)

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.2.1...0.2.2) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.2.1...0.2.2.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.2.1...0.2.2.patch)

## [0.2.1](https://github.com/seapagan/simple-toml-settings/releases/tag/0.2.1) (2023-10-12)

**Bug Fixes**

- Add 'py.typed' file so mypy can typecheck package ([#16](https://github.com/seapagan/simple-toml-settings/pull/16)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump faker from 19.8.0 to 19.9.0 ([#15](https://github.com/seapagan/simple-toml-settings/pull/15)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mypy from 1.5.1 to 1.6.0 ([#14](https://github.com/seapagan/simple-toml-settings/pull/14)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pylint from 2.17.7 to 3.0.1 ([#13](https://github.com/seapagan/simple-toml-settings/pull/13)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump faker from 19.6.2 to 19.8.0 ([#12](https://github.com/seapagan/simple-toml-settings/pull/12)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-material from 9.4.4 to 9.4.5 ([#11](https://github.com/seapagan/simple-toml-settings/pull/11)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.2.0...0.2.1) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.2.0...0.2.1.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.2.0...0.2.1.patch)

## [0.2.0](https://github.com/seapagan/simple-toml-settings/releases/tag/0.2.0) (2023-10-10)

**New Features**

- Add a hook, called if the config file is missing and freshly created ([#10](https://github.com/seapagan/simple-toml-settings/pull/10)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump pylint-pydantic from 0.2.4 to 0.3.0 ([#9](https://github.com/seapagan/simple-toml-settings/pull/9)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump actions/checkout from 3 to 4 ([#7](https://github.com/seapagan/simple-toml-settings/pull/7)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/simple-toml-settings/compare/0.1.0...0.2.0) | [`Diff`](https://github.com/seapagan/simple-toml-settings/compare/0.1.0...0.2.0.diff) | [`Patch`](https://github.com/seapagan/simple-toml-settings/compare/0.1.0...0.2.0.patch)

## [0.1.0](https://github.com/seapagan/simple-toml-settings/releases/tag/0.1.0) (2023-10-09)

**Merged Pull Requests**

- Add test workflow to Github Actions ([#2](https://github.com/seapagan/simple-toml-settings/pull/2)) by [seapagan](https://github.com/seapagan)

**Refactoring**

- Rename main settings class ([#5](https://github.com/seapagan/simple-toml-settings/pull/5)) by [seapagan](https://github.com/seapagan)

**Documentation**

- Add basic documentation for the library ([#3](https://github.com/seapagan/simple-toml-settings/pull/3)) by [seapagan](https://github.com/seapagan)

---
*This changelog was generated using [github-changelog-md](http://changelog.seapagan.net/) by [Seapagan](https://github.com/seapagan)*
